@@ -89,6 +89,12 @@ ObjectiveFSelect = R6Class("ObjectiveFSelect",
       aggr = bmr$aggregate(self$measures)
       y = map_chr(self$measures, "id")
 
+      # add runtime
+      time = map_dbl(bmr$resample_results$resample_result, function(rr) {
+        sum(map_dbl(rr$learners, function(l) sum(l$timings)))
+      })
+      aggr[, "runtime_learners" := time]
+
       if (self$store_benchmark_result) {
         self$archive$benchmark_result =
           if (is.null(self$archive$benchmark_result)) {
@@ -96,9 +102,9 @@ ObjectiveFSelect = R6Class("ObjectiveFSelect",
           } else {
             self$archive$benchmark_result$combine(bmr)
           }
-        cbind(aggr[, y, with = FALSE], uhash = bmr$uhashes)
+        cbind(aggr[, c(y, "runtime_learners"), with = FALSE], uhash = bmr$uhashes)
       } else {
-        aggr[, y, with = FALSE]
+        aggr[, c(y, "runtime_learners"), with = FALSE]
       }
     }
   )
